bound property
double
get
bound
The most any fragment is displaced by this wave.
Implementation
double get bound => front.abs() + dimple.abs();
The most any fragment is displaced by this wave.
double get bound => front.abs() + dimple.abs();