generation property
int
get
generation
How many frames have been published. The counter that tells a surface with no proxy apart from a surface whose proxy never updates.
Implementation
int get generation => _generation;